==> checker-3.20.0.jar: annotated-jdk/src/java.base/share/classes/java/util/jar/JavaUtilJarAccessImpl.java <==
/*
 * Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util.jar;

import org.checkerframework.checker.interning.qual.UsesObjectEquals;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.io.IOException;
import java.net.URL;
import java.security.CodeSource;
import java.util.Enumeration;
import java.util.List;
import jdk.internal.misc.JavaUtilJarAccess;

@AnnotatedFor({ "interning" })
@UsesObjectEquals
public class JavaUtilJarAccessImpl implements JavaUtilJarAccess {

    public boolean jarFileHasClassPathAttribute(JarFile jar) throws IOException;

    public CodeSource[] getCodeSources(JarFile jar, URL url);

    public CodeSource getCodeSource(JarFile jar, URL url, String name);

    public Enumeration<String> entryNames(JarFile jar, CodeSource[] cs);

    public Enumeration<JarEntry> entries2(JarFile jar);

    public void setEagerValidation(JarFile jar, boolean eager);

    public List<Object> getManifestDigests(JarFile jar);
}

==> checker-3.49.5.jar: annotated-jdk/src/java.base/share/classes/java/util/jar/JavaUtilJarAccessImpl.java <==
/*
 * Copyright (c) 2002, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util.jar;

import org.checkerframework.checker.interning.qual.UsesObjectEquals;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.io.IOException;
import java.net.URL;
import java.security.CodeSource;
import java.util.Enumeration;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import jdk.internal.access.JavaUtilJarAccess;

@AnnotatedFor({ "interning" })
@UsesObjectEquals
class JavaUtilJarAccessImpl implements JavaUtilJarAccess {

    public boolean jarFileHasClassPathAttribute(JarFile jar) throws IOException;

    public CodeSource[] getCodeSources(JarFile jar, URL url);

    public CodeSource getCodeSource(JarFile jar, URL url, String name);

    public Enumeration<String> entryNames(JarFile jar, CodeSource[] cs);

    public Enumeration<JarEntry> entries2(JarFile jar);

    public void setEagerValidation(JarFile jar, boolean eager);

    public List<Object> getManifestDigests(JarFile jar);

    public Attributes getTrustedAttributes(Manifest man, String name);

    public void ensureInitialization(JarFile jar);

    public boolean isInitializing();

    public JarEntry entryFor(JarFile jar, String name);
}
